import React, { Component, Fragment } from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';

import Button from 'reactstrap/lib/Button';
import Label from 'reactstrap/lib/Label';
import FormGroup from 'reactstrap/lib/FormGroup';
import Input from 'reactstrap/lib/Input';

import { IconEth } from '../../icons/icon-eth/icon-eth';
import { IconScr } from '../../icons/icon-scr/icon-scr';
import { InputWithIcon } from '../../form/input-with-icon/input-with-icon';

export class CalcAmount extends Component {
  static propTypes = {
    rate: PropTypes.string,
    ethValue: PropTypes.string,
    scrValue: PropTypes.string,
    maxAmount: PropTypes.string,
    onEthChange: PropTypes.func.isRequired,
    onScrChange: PropTypes.func.isRequired,
    onContinueClick: PropTypes.func.isRequired,
  };

  static defaultProps = {
    rate: null,
    ethValue: '',
    scrValue: '',
    maxAmount: null,
  };

  state = {
    checked: false,
  };

  toggleCheck = () => this.setState(prevState => ({ checked: !prevState.checked }));

  render() {
    const { checked } = this.state;
    const {
      ethValue, scrValue, onEthChange, onScrChange, rate, maxAmount, onContinueClick,
    } = this.props;

    return (
      <Fragment>
        <h3 className="text-center mb-4">
          <FormattedMessage id="theme.balance.refill.calc-step.title" />
        </h3>

        <div className="d-flex align-items-center mb-3_5">
          <InputWithIcon icon={<IconEth />} onChange={onEthChange} value={ethValue} className="pr-5" />
          <h5 className="mx-1_5 text-gray-dark-hint">=</h5>
          <InputWithIcon icon={<IconScr />} onChange={onScrChange} value={scrValue} className="pr-5" />
        </div>

        <div className="d-flex justify-content-between mb-1">
          <span className="text-gray-dark-hint">
            <FormattedMessage id="theme.balance.refill.calc-step.rate" />
          </span>
          <span className="h5p">1 SCR = {rate} ETH</span>
        </div>
        <div className="d-flex justify-content-between">
          <span className="text-gray-dark-hint">
            <FormattedMessage id="theme.balance.refill.calc-step.max.title" />
          </span>
          <span className="h5p">
            <FormattedMessage id="theme.balance.refill.calc-step.max.value" values={{ value: maxAmount }} />
          </span>
        </div>

        <div className="mt-2_5 mb-4 p-1_5 text-small text-gray-dark-secondary bg-shade-s20">
          <FormattedMessage id="theme.balance.refill.calc-step.description" />
        </div>

        <Button color="primary" block className="mb-2" disabled={!checked} onClick={onContinueClick}>
          <FormattedMessage id="wallet.sign-in-first.continue.button" />
        </Button>

        <FormGroup check>
          <Label check>
            <Input type="checkbox" onClick={this.toggleCheck} />
            <span className="text-gray-dark-secondary">
              <FormattedMessage id="theme.balance.refill.calc-step.checkbox" />
            </span>
          </Label>
        </FormGroup>
      </Fragment>
    );
  }
}
