import React from 'react';
import Button from 'reactstrap/lib/Button';

import { CalcAmount } from './calc-amount';
import { InputWithIcon } from '../../form/input-with-icon/input-with-icon';

const props = {
  rate: '0.2',
  maxAmount: '1200',
  ethValue: '2',
  scrValue: '233',
  onEthChange: jest.fn(),
  onScrChange: jest.fn(),
  onContinueClick: jest.fn(),
};
let wrapper;

describe('<CalcAmount />', () => {
  wrapper = shallow(<CalcAmount {...props} />);

  test('should match snapshot', () => {
    expect(wrapper).toMatchSnapshot();
  });

  test('should change state value `checked` after trigger `toggleCheck`', () => {
    expect(wrapper.instance().state.checked).toEqual(false);
    wrapper.instance().toggleCheck();
    expect(wrapper.instance().state.checked).toEqual(true);
  });

  test('click on `continue button` should trigger `onContinueClick` prop', () => {
    wrapper.find(Button).simulate('click');
    expect(props.onContinueClick).toHaveBeenCalledTimes(1);
  });

  test('change value in the fist `InputWithIcon` component should trigger `onEthChange` prop', () => {
    wrapper.find(InputWithIcon).first().simulate('change', { target: { value: '7' } });
    expect(props.onEthChange).toHaveBeenCalledWith({ target: { value: '7' } });
  });

  test('change value in the last `InputWithIcon` component should trigger `onScrChange` prop', () => {
    wrapper.find(InputWithIcon).last().simulate('change', { target: { value: '3' } });
    expect(props.onScrChange).toHaveBeenCalledWith({ target: { value: '3' } });
  });
});
