import React from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';
import QRCode from 'qrcode.react';

import Button from 'reactstrap/lib/Button';

import { IconEth } from '../../icons/icon-eth/icon-eth';
import { IconScr } from '../../icons/icon-scr/icon-scr';
import { InputWithIcon } from '../../form/input-with-icon/input-with-icon';
import { InputWithClipboard } from '../../form/input-with-clipboard/input-with-clipboard';

import './send-amount.scss';

export const SendAmount = ({
  ethValue, scrValue, onEthChange, onScrChange, rate, maxAmount, onDoneClick, scrAddress,
}) => (
  <div className="send-amount-step">
    <h3 className="text-center mb-4">
      <FormattedMessage id="theme.balance.refill.send-step.title" />
    </h3>

    <div className="qr mx-auto mb-4 border border-shade-s30 rounded">
      <QRCode className="m-1_5" value={scrAddress} />
    </div>

    <InputWithClipboard value={scrAddress} />

    <div className="divider my-3" />

    <div className="d-flex align-items-center mb-3_5">
      <InputWithIcon icon={<IconEth />} onChange={onEthChange} value={ethValue} className="pr-5" />
      <h5 className="mx-1_5 text-gray-dark-hint">=</h5>
      <InputWithIcon icon={<IconScr />} onChange={onScrChange} value={scrValue} className="pr-5" />
    </div>

    <div className="d-flex justify-content-between mb-1">
      <span className="text-gray-dark-hint">
        <FormattedMessage id="theme.balance.refill.calc-step.rate" />
      </span>
      <span className="h5p">1 SCR = {rate} ETH</span>
    </div>
    <div className="d-flex justify-content-between">
      <span className="text-gray-dark-hint">
        <FormattedMessage id="theme.balance.refill.calc-step.max.title" />
      </span>
      <span className="h5p">
        <FormattedMessage id="theme.balance.refill.calc-step.max.value" values={{ value: maxAmount }} />
      </span>
    </div>

    <Button outline block className="mt-4" onClick={onDoneClick}>
      <FormattedMessage id="wallet.payment.send.button.done" />
    </Button>
  </div>
);

SendAmount.propTypes = {
  rate: PropTypes.string,
  ethValue: PropTypes.string,
  scrValue: PropTypes.string,
  maxAmount: PropTypes.string,
  scrAddress: PropTypes.string,
  onEthChange: PropTypes.func.isRequired,
  onScrChange: PropTypes.func.isRequired,
  onDoneClick: PropTypes.func.isRequired,
};

SendAmount.defaultProps = {
  rate: null,
  ethValue: '',
  scrValue: '',
  maxAmount: null,
  scrAddress: null,
};
